@@ -16,16 +16,36 @@ from io import BytesIO
 from typing import Callable, Generator, Iterable, Optional, TypeVar
 
 __all__ = [
-    'PdfError', 'PdfReadError', 'PdfStrictReadError',
-    'PdfWriteError', 'PdfStreamError', 'IndirectObjectExpected',
-    'get_and_apply', 'OrderedEnum', 'StringWithLanguage',
+    'PdfError',
+    'PdfReadError',
+    'PdfStrictReadError',
+    'PdfWriteError',
+    'PdfStreamError',
+    'IndirectObjectExpected',
+    'get_and_apply',
+    'OrderedEnum',
+    'StringWithLanguage',
     'is_regular_character',
-    'read_non_whitespace', 'read_until_whitespace', 'read_until_regex',
-    'skip_over_whitespace', 'skip_over_comment', 'instance_test', 'peek',
-    'assert_writable_and_random_access', 'prepare_rw_output_stream',
+    'read_non_whitespace',
+    'read_until_whitespace',
+    'read_until_delimiter',
+    'read_until_regex',
+    'skip_over_whitespace',
+    'skip_over_comment',
+    'instance_test',
+    'peek',
+    'assert_writable_and_random_access',
+    'prepare_rw_output_stream',
     'finalise_output',
-    'DEFAULT_CHUNK_SIZE', 'chunked_write', 'chunked_digest', 'chunk_stream',
-    'ConsList', 'Singleton', 'rd', 'isoparse', 'lift_iterable_async'
+    'DEFAULT_CHUNK_SIZE',
+    'chunked_write',
+    'chunked_digest',
+    'chunk_stream',
+    'ConsList',
+    'Singleton',
+    'rd',
+    'isoparse',
+    'lift_iterable_async',
 ]
 
 import pytz
@@ -40,7 +60,6 @@ rd = lambda x: round(x, 4)
 
 
 def instance_test(cls):
-
     return lambda x: isinstance(x, cls)
 
 
@@ -58,11 +77,42 @@ def pair_iter(lst):
         yield x1, x2
 
 
-def read_until_whitespace(stream, maxchars=None):
+PDF_WHITESPACE = b' \n\r\t\f\x00'
+PDF_DELIMITERS = b'()<>[]{}/%'
+
+
+def read_until_whitespace(stream, maxchars: Optional[int] = None) -> bytes:
     """
     Reads non-whitespace characters and returns them.
-    Stops upon encountering whitespace or when maxchars is reached.
+    Stops upon encountering whitespace, or, if ``maxchars`` is not ``None``,
+    when maxchars is reached.
+
+    :param stream:
+        stream to read
+    :param maxchars:
+        maximal number of bytes to read before returning
     """
+
+    return _read_until_class(PDF_WHITESPACE, stream, maxchars=maxchars)
+
+
+def read_until_delimiter(stream) -> bytes:
+    """
+    Read until a token delimiter (i.e. a delimiter character or a PDF
+    whitespace character) is encountered, and rewind the stream to the previous
+    character.
+
+    :param stream:
+        A stream.
+    :return:
+        The bytes read.
+    """
+    result = _read_until_class(PDF_WHITESPACE + PDF_DELIMITERS, stream)
+    stream.seek(-1, os.SEEK_CUR)
+    return result
+
+
+def _read_until_class(class_chars: bytes, stream, maxchars=None) -> bytes:
     if maxchars == 0:
         return b''
 
@@ -70,16 +120,13 @@ def read_until_whitespace(stream, maxchars=None):
         stop_at = None if maxchars is None else stream.tell() + maxchars
         while maxchars is None or stream.tell() < stop_at:
             tok = stream.read(1)
-            if tok.isspace() or not tok:
+            if tok in class_chars or not tok:
                 break
             yield tok
+
     return b''.join(_build())
 
 
-PDF_WHITESPACE = b' \n\r\t\f\x00'
-PDF_DELIMITERS = b'()<>[]{}/%'
-
-
 def is_regular_character(byte_value: int):
     return byte_value not in PDF_WHITESPACE and byte_value not in PDF_DELIMITERS
 
@@ -111,7 +158,7 @@ def read_non_whitespace(stream, seek_back=False, allow_eof=False):
 
 def skip_over_whitespace(stream, stop_after_eol=False) -> bool:
     """
-    Similar to readNonWhitespace, but returns a Boolean if more than
+    Similar to :func:`read_non_whitespace`, but returns a ``bool`` if more than
     one whitespace character was read.
 
     Will return the cursor to before the first non-whitespace character
@@ -121,13 +168,16 @@ def skip_over_whitespace(stream, stop_after_eol=False) -> bool:
     cnt = 0
     while tok in PDF_WHITESPACE:
         tok = stream.read(1)
+        if not tok:
+            raise PdfStreamError("Stream ended prematurely")
         cnt += 1
         if stop_after_eol:
             if tok == b'\n':
                 return cnt > 1
             elif tok == b'\r':
-                # read the next char and check if it's a LF
-                if stream.read(1) == b'\n':
+                # read the next char and check if it's a LF (or EOF)
+                nxt = stream.read(1)
+                if nxt == b'\n' or not nxt:
                     return cnt > 1
                 # if not, break here; we need to seek back one position
                 # (CR by itself also counts as an EOL sequence)
@@ -138,22 +188,43 @@ def skip_over_whitespace(stream, stop_after_eol=False) -> bool:
 
 
 def skip_over_comment(stream) -> bool:
+    """
+    Skip over a comment and position the cursor at the first byte after
+    the EOL sequence following the comment. If there is no comment under
+    the cursor, do nothing.
+
+    :param stream:
+        stream to read
+    :return:
+        ``True`` if a comment was read.
+    """
     tok = stream.read(1)
     stream.seek(-1, 1)
     if tok == b'%':
-        while tok not in (b'\n', b'\r'):
+        while tok not in (b'\n', b'\r', b''):
             tok = stream.read(1)
+        # read the next char and check if it's a LF (or EOF)
+        nxt = stream.read(1)
+        if nxt and nxt != b'\n':
+            # ...if not, rewind
+            stream.seek(-1, os.SEEK_CUR)
         return True
     return False
 
 
-def read_until_regex(stream, regex, ignore_eof=False):
+def read_until_regex(stream, regex, ignore_eof: bool = False):
     """
     Reads until the regular expression pattern matched (ignore the match)
-    Raise PdfStreamError on premature end-of-file.
-    :param bool ignore_eof: If true, ignore end-of-line and return immediately
-    :param regex: regex to match
-    :param stream: stream to search
+    Raise :class:`PdfStreamError` on premature end-of-file.
+
+    :param stream:
+        stream to search
+    :param regex:
+        regex to match
+    :param ignore_eof:
+        if true, ignore end-of-line and return immediately
+    :raises PdfStreamError:
+        on premature EOF
     """
     name = b''
     while True:
@@ -166,8 +237,8 @@ def read_until_regex(stream, regex, ignore_eof=False):
                 raise PdfStreamError("Stream has ended unexpectedly")
         m = regex.search(tok)
         if m is not None:
-            name += tok[:m.start()]
-            stream.seek(m.start()-len(tok), 1)
+            name += tok[: m.start()]
+            stream.seek(m.start() - len(tok), 1)
             break
         name += tok
     return name
@@ -188,7 +259,6 @@ class StringWithLanguage:
 
 
 class PdfError(Exception):
-
     def __init__(self, msg: str, *args):
         self.msg = msg
         super().__init__(msg, *args)
@@ -309,7 +379,6 @@ class VersionEnum(Enum):
 
 
 class LazyJoin:
-
     def __init__(self, sep, iterator):
         self.sep = sep
         self.iterator = iterator
@@ -331,8 +400,9 @@ Y = TypeVar('Y')
 R = TypeVar('R')
 
 
-def map_with_return(gen: Generator[X, None, R], func: Callable[[X], Y])\
-        -> Generator[Y, None, R]:
+def map_with_return(
+    gen: Generator[X, None, R], func: Callable[[X], Y]
+) -> Generator[Y, None, R]:
     while True:
         try:
             yield func(next(gen))
@@ -378,7 +448,6 @@ def chunked_write(temp_buffer: bytearray, stream, output, max_read=None):
 
 
 class Singleton(type):
-
     def __new__(mcs, name, bases, dct):
         cls = type.__new__(mcs, name, bases, dct)
         instance = type.__call__(cls)
@@ -426,9 +495,7 @@ def assert_writable_and_random_access(output):
     #  case, the write error would only happen *after* the signing/updating
     #  operations are done. We want to avoid that scenario.
     if not output.writable():
-        raise IOError(
-            "Output buffer is not writable"
-        )  # pragma: nocover
+        raise IOError("Output buffer is not writable")  # pragma: nocover
     return output.seekable() and output.readable()
 
 
